@@ -20,10 +20,12 @@ import os
 import signal
 import subprocess
 
-from dirspec.basedir import load_data_paths
 from distutils.spawn import find_executable
 from urllib import quote
 
+from ubuntuone.devtools.services import find_config_file
+DBUS_CONFIG_FILE = 'dbus-session.conf.in'
+
 
 class DBusLaunchError(Exception):
     """Error while launching dbus-daemon"""
@@ -44,42 +46,25 @@ class DBusRunner(object):
         self.running = False
         self.config_file = None
 
-    def _find_config_file(self, tempdir=None):
+    def _generate_config_file(self, tempdir=None):
         """Find the first appropriate dbus-session.conf to use."""
-        # In case we're running from within the source tree
-        path = os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                            os.path.pardir, os.path.pardir,
-                                            os.path.pardir,
-                                            "data", "dbus-session.conf.in"))
-        if not os.path.exists(path):
-            # Use the installed file in $pkgdatadir as source
-            for path in load_data_paths("ubuntuone-dev-tools",
-                                        "dbus-session.conf.in"):
-                if os.path.exists(path):
-                    break
-
-        # Check to make sure we didn't just fall out of the loop
-        if not os.path.exists(path):
-            raise IOError('Could not locate suitable dbus-session.conf.in')
-
+        # load the config file
+        path = find_config_file(DBUS_CONFIG_FILE)
+        # replace config settings
         self.config_file = os.path.join(tempdir, 'dbus-session.conf')
         dbus_address = 'unix:tmpdir=%s' % quote(tempdir)
         with open(path) as in_file:
             content = in_file.read()
             with open(self.config_file, 'w') as out_file:
                 out_file.write(content.replace('@ADDRESS@', dbus_address))
-                out_file.close()
-            in_file.close()
 
     def start_service(self, tempdir=None):
         """Start our own session bus daemon for testing."""
-        if not tempdir:
-            tempdir = os.path.join(os.getcwd(), '_trial_temp')
         dbus = find_executable("dbus-daemon")
         if not dbus:
             raise NotFoundError("dbus-daemon was not found.")
 
-        self._find_config_file(tempdir)
+        self._generate_config_file(tempdir)
 
         dbus_args = ["--fork",
                      "--config-file=" + self.config_file,
